/**
 *Core Configuration.
 *
 *@author  			Qian Chen
 *@coplyright 		Copyright (c) 2015, zuber.im
 *@lincence
 */

(function(){
	'use strict';

	/* @ngInject */
	function onConfig($urlRouterProvider, $ionicConfigProvider, $httpProvider, localStorageServiceProvider, RestangularProvider, RESTFUL_BASE_URL) {
		//fix the difference in layouts between android and ios
		$ionicConfigProvider.platform.ios.tabs.style('standard');
		$ionicConfigProvider.platform.ios.tabs.position('bottom');
		$ionicConfigProvider.platform.android.tabs.style('standard');
		$ionicConfigProvider.platform.android.tabs.position('bottom');
		$ionicConfigProvider.platform.ios.navBar.alignTitle('center');
		$ionicConfigProvider.platform.android.navBar.alignTitle('left');
		$ionicConfigProvider.platform.ios.backButton.previousTitleText('').icon('ion-ios-arrow-thin-left');
		$ionicConfigProvider.platform.android.backButton.previousTitleText('').icon('ion-android-arrow-back');
		$ionicConfigProvider.platform.ios.views.transition('ios');
		$ionicConfigProvider.platform.android.views.transition('android');
		$ionicConfigProvider.scrolling.jsScrolling(false);
		$ionicConfigProvider.form.checkbox('circle');

		 //define the web app's header for ajax request
		$httpProvider.defaults.headers.post['Content-Type'] = 'application/x-www-form-urlencoded';
		$httpProvider.defaults.headers.post['Accept'] = 'application/json, text/html, */*; q=0.01';
		$httpProvider.defaults.headers.post['X-Requested-With'] = 'XMLHttpRequest';

		// use "ionic-photo-gallery" as a localStorage name prefix so app doesn’t accidently read data from another app using the same variable names
        //localStorageServiceProvider.setPrefix('ionic-photo-gallery');
		/*******************************************************************
		* Route provider configuration based on these config constant values
		********************************************************************/
		//set Restfull base API route
		RestangularProvider.setBaseUrl(RESTFUL_BASE_URL);

		$urlRouterProvider.otherwise('/roomsearch');
	}

	/* @ngInject */
	function onRun($ionicPlatform, $rootScope, $state, $ionicHistory, HintService, Authentication, ProfileService, MessageService, jPushService, DeviceService, localStorageService, TEST_MODE) {

		$ionicPlatform.ready(function() {

      $ionicPlatform.registerBackButtonAction(function(event) {

        if( $state.is('app.roomsearch') ) {
          HintService.comfirmHint("退出应用", "您确定要退出zuber吗", function() {
            ionic.Platform.exitApp();
            return false;
          })
        }

        if( $rootScope.beginRegister ) {
          event.preventDefault();
          return false;
        }

        if ( !$rootScope.beginRegister ) {
          $ionicHistory.goBack();
        }
      }, 100);

			//save user profile details to $rootscope

			if ( !!Authentication.getCurrentUserId() ) {
				$rootScope.loginState = true;
				//get user info from cache
				$rootScope.me 		  = JSON.parse( localStorageService.get('user') );
				//renew user information
				ProfileService.getUser().then(function(data) {
			 		$rootScope.me        = data.result;
					localStorageService.set( "user", angular.toJson( data.result ) );
			 	});
			 	//add jpush listener
			    //checknew
			    MessageService.notification().then(function(data) {
			    	if ( data.result == 1 ) {
			    		$rootScope.hasNewMessage = true;
			    	}
			    })

			} else {
				$rootScope.loginState = false;
			}

			//upload device information
			if (!TEST_MODE) {
				var deviceInfo,
	                networkType,
	                appVersion;

		        ionic.Platform.ready(function() {
		            deviceInfo  = ionic.Platform.device();
		            networkType = navigator.connection.type;
		        });

		        cordova.getAppVersion.getVersionNumber().then(function (version) {
		            appVersion = version;
		            DeviceService.getInfor(deviceInfo, appVersion, networkType).then(function(data) {
		            	console.log(angular.toJson(data));
			        	$rootScope.moduleCtrl = data.result.user_register_toggle;
			        	localStorageService.set('moduleCtrl', $rootScope.moduleCtrl);
			        });
		        });
			} else {
				$rootScope.moduleCtrl = true;
			}


			//initial
			$rootScope.hasNewMessage = false;
			$rootScope.throwOnce     = true;

			window.open = cordova.InAppBrowser.open;

			//get jPush registration id and save it to localstorage
		   	window.plugins.jPushPlugin.init();

			document.addEventListener("jpush.receiveNotification",function(){
			    $rootScope.hasNewMessage = true;
			    $rootScope.$digest();
			},false);

			document.addEventListener("jpush.receiveMessage",function(){
			    $rootScope.hasNewMessage = true;
			    $rootScope.$digest();
			},false);

			document.addEventListener("jpush.openNotification",function(){
			    $rootScope.hasNewMessage = true;
			    $rootScope.$digest();
			    $state.go("app.messages", {}, { reload: true });
			},false);

			//let the default accessory bar show
			if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
				cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
			}

			if (window.StatusBar) {
		      StatusBar.styleLightContent();
		    }


		});
	}






	angular
	.module('app.core')
	.config(onConfig)
	.run(onRun)
	.constant('TEST_MODE', false)
	.constant("API_VERSION", 'v2/')
	//.constant('RESTFUL_BASE_URL','http://beta.api.zuber.im');       //test
	//.constant('RESTFUL_BASE_URL','http://192.168.0.104/api/api/web/index.php'); //dog
	.constant('RESTFUL_BASE_URL','https://api.zuber.im/v2');         //production
})()
