/**
 *Token service.
 *
 *@author  			Qian Chen 
 *@coplyright 		Copyright (c) 2015, zuber.im
 *@lincence
 */
(function(){
	'user strict';

	/**
     * @ngdoc service
     * @name Token
     * @module app.core
     * @requires localStorageService
     * 
     *
     * @description
     * The `Token` service get & store token to local storage, cookie or memory.
     *
	 * @ngInject
	 */
	function Token($http, $rootScope, Restangular, localStorageService, TEST_MODE) {
		/**
		 * @type {string}
		 * @private
		 */
		var _uidStorageKey = 'uid',
			_tokenStorageKey = 'token',
			_secretStorageKey = 'secret';
		/**
		 * @type {string}
		 * @private
		 */
		var _cachedUid = '',
			_cachedToken = '',
			_cachedSecret = '';

		/**
		 * @ngdoc method
		 * @name Token#set
		 * @description Set Token
		 * @param {string} uid token secret
		 */
		var set = function(uid, token, secret) {
			_cachedUid = uid;
			localStorageService.set(_uidStorageKey, uid);

			_cachedToken = token;
			localStorageService.set(_tokenStorageKey, token);

			_cachedSecret = secret;
			localStorageService.set(_secretStorageKey, secret);
		}
		/**
		 * @ngdoc method
		 * @name Token#getUserId
		 * @description Get uid
		 * @returns {string} user id
		 */
		var getUid = function() {
			return localStorageService.get(_uidStorageKey);
		}
		var getApiUid = function() {
			var _apiUid = (!!localStorageService.get(_uidStorageKey)) ?  '/' + localStorageService.get(_uidStorageKey) : "";
			
			return _apiUid;
		}
		var getToken = function() {
		 	if (!_cachedToken) {
		 		_cachedToken = localStorageService.get(_tokenStorageKey);
		 	}
		 	return _cachedToken;
		 }
		 var getSecret = function() {
		 	if (!_cachedSecret) {
		 		_cachedSecret = localStorageService.get(_secretStorageKey);
		 	}
		 	return _cachedSecret;
		 }
		/**
		 * @ngdoc method
		 * @name Token#clear
		 * @description Get uid token secret
		 * @params {string}
		 * @returns {string} usd token secret
		 */
		var clear = function() {
			_cachedUid = null;
			localStorageService.remove(_uidStorageKey);

			_cachedToken = null;
			localStorageService.remove(_tokenStorageKey);

			_cachedSecret = null;
			localStorageService.remove(_secretStorageKey);

			$rootScope.me = null;
			localStorageService.remove('user');
		};

		return {
			set: 	    set,
			getUid: 	getUid,
			getApiUid:  getApiUid,
			getToken:   getToken,
			getSecret:  getSecret,
			clear: 		clear
		}



	}


	angular
	.module('app.core')
	.factory('Token',Token);
})()