/**
 *Comment service.
 *
 *@author  			Qian Chen 
 *@coplyright 		Copyright (c) 2015, zuber.im
 *@lincence
 */
(function() {
	"user strict";
	/**
     * @ngdoc service
     * @name Commentervice
     * @module app.core
     * @requires $http, Restangular, Token, Signature
     * @description
     * Service to get the search data.
     *
     * @ngInject
     */
    function CommentService($http, Restangular, Token, Signature) {
    	return {
    		/**
             * @ngdoc method
             * @name CommentService:list
             * @params {object} params,category
             * @description
             * get comment list.
             *
             * @returns {promise} A promise which is resolved in comment data.
             */
            list: function(params, category) {
            	var _postfix = "/" + category;
                var _uid = Token.getApiUid();
                var _api = "comments" + _uid + _postfix

                Signature.set(_api, {}, 'get');

            	return Restangular
            		   .one(_api)
            	       .get(params); 
            },
            /**
             * @ngdoc method
             * @name CommentService:getListByRid
             * @params {object} params
             * @description
             * get comment list by room id.
             *
             * @returns {promise} A promise which is resolved in comment data.
             */
            getListByRid: function(params) {
                var _uid = Token.getApiUid();
                var _api = "comments" + _uid + "/room"

                Signature.set(_api, {}, 'get');

                return Restangular
                       .one(_api)
                       .get(params); 
            },
            /**
             * @ngdoc method
             * @name CommentService:reply
             * @params {object} params
             * @description
             * send comment.
             *
             * @returns {promise} send comment response.
             */
            reply: function(params) {
                var _uid = Token.getApiUid();
                var _api = "comments" + _uid;

                Signature.set(_api, params, 'post');

            	return Restangular
            		   .all(_api)
            		   .post(params);
            },
            /**
             * @ngdoc method
             * @name CommentService:remove
             * @params {object} params
             * @description
             * remove comment.
             *
             * @returns {promise} remove comment response.
             */
            remove: function(params) {
                var _uid = Token.getApiUid();
                var _api = "comments" + _uid;

                Signature.set(_api, {}, 'delete');

            	return Restangular
            		   .one(_api)
            		   .remove(params);
            },
            /**
             * @ngdoc method
             * @name CommentService:set
             * @params {object} params
             * @description
             * set read.
             *
             * @returns {promise} set read response.
             */
            set: function(params) {
                var _uid = Token.getApiUid();
                var _api = "comments" + _uid;

                Signature.set(_api, params, 'put');

            	return Restangular
            		   .one(_api)
            		   .customPUT(params);
            }
    	}

    }




	angular
	.module('app.core')
	.factory('CommentService', CommentService)
})()