/**
 * Gallery service.
 *
 * @author  			Qian Chen 
 * @coplyright 		Copyright (c) 2015, zuber.im
 * @lincence
 */
(function() {
	'user strict';
	/**
     * @ngdoc service
     * @name Galleryservice
     * @module app.core
     * @requires $http, Restangular
     * @description
     * user for railway and region information from different city
     *
     * @ngInject
     */
    function GalleryService($http, Restangular, Token, Signature) {
    	return {
    		/**
             * @ngdoc method
             * @name GalleryService:getRailwayByCity
             * @params {string} city
             * @description
             * get railway information by city.
             *
             * @returns {promise} A data which is resolved in railway data.
             */
    		get: function() {
    			var _uid = Token.getApiUid();
                var _api = 'files' + _uid;
                Signature.set(_api, {}, 'get');

                return Restangular
                       .one(_api)
                       .get()
    		},
            /**
             * @ngdoc method
             * @name GalleryService:getDividerFilterByCity
             * @params {string} number
             * @description
             * get image tokens from server.
             *
             * @returns {promise} A data which is resolved in divider data.
             */
            getTokens: function(params) {
                var _uid = Token.getApiUid();
                var _api = 'files' + _uid + "/token";
                Signature.set(_api, {}, 'get');

                return Restangular
                       .one(_api)
                       .get(params);
            },
    		/**
             * @ngdoc method
             * @name GeoService:getDividerFilterByCity
             * @params {string} city
             * @description
             * get divider information by city.
             *
             * @returns {promise} A data which is resolved in divider data.
             */
    		upload: function(filePath, uploadURL, token, accept, callback) {
                var _uid = Token.getApiUid();
                var _api = 'files' + _uid + "/error";
                

    			var up = new FileTransfer();

                var onSuccess = function() {
                    callback();
                }

                var fail = function(er) {
                    var _param = {
                        code : er.http_status,
                        msg  : JSON.parse(er.body).error
                    }
                    Signature.set(_api, _param, 'post');
                    Restangular.all(_api).post(_param).then(function() {
                        return false;
                    })
                }

                var fileoptions = new FileUploadOptions();

                var getDynamicToken = function () {
                    fileoptions.params = {
                        'token'  : token,
                        'accept' : accept
                    }
                    return fileoptions
                }

                up.upload( filePath, encodeURI(uploadURL), onSuccess, fail, getDynamicToken() );
    		},
            /**
             * @ngdoc method
             * @name GeoService:getDividerFilterByCity
             * @params {string} city
             * @description
             * get divider information by city.
             *
             * @returns {promise} A data which is resolved in divider data.
             */
            deleteImage: function(params) {
                var _uid = Token.getApiUid();
                var _api = 'files' + _uid;
                Signature.set(_api, {}, 'delete');

                return Restangular
                       .one(_api)
                       .remove(params)
            }

    	}
    }

	angular
	.module('app.core')
	.factory('GalleryService',GalleryService);
})()