/**
 *Geography service.
 *
 *@author  			Qian Chen 
 *@coplyright 		Copyright (c) 2015, zuber.im
 *@lincence
 */
(function() {
	'user strict';
	/**
     * @ngdoc service
     * @name Geoservice
     * @module app.core
     * @requires $http, Restangular
     * @description
     * user for railway and region information from different city
     *
     * @ngInject
     */
    function GeoService($http, Restangular, Token, Signature) {
    	return {
    		/**
             * @ngdoc method
             * @name GeoService:getRailwayByCity
             * @params {string} city
             * @description
             * get railway information by city.
             *
             * @returns {promise} A data which is resolved in railway data.
             */
    		getRailwayByCity: function(city) {
    			return $http.get('./js/core/config/location/'+city+'/railway.js')
    		},
    		/**
             * @ngdoc method
             * @name GeoService:getDividerFilterByCity
             * @params {string} city
             * @description
             * get divider information by city.
             *
             * @returns {promise} A data which is resolved in divider data.
             */
    		getDividerFilterByCity: function(city) {
    			return $http.get('./js/core/config/location/'+city+'/divider.js')
    		},
            /**
             * @ngdoc method
             * @name GeoService:getLocation
             * @params {string} coordnates
             * @description
             * get detail location by coordnates.
             *
             * @returns {promise} A data which is resolved in location data.
             */
            map: function(params) {
                var _uid = Token.getApiUid();
                var _api = 'commons' + _uid + "/map";
                Signature.set(_api, {}, 'get');

                return Restangular
                       .one(_api)
                       .get(params)
            },

    	}
    }

	angular
	.module('app.core')
	.factory('GeoService',GeoService);
})()