/**
 *Comment service.
 *
 *@author  			Qian Chen
 *@coplyright 		Copyright (c) 2015, zuber.im
 *@lincence
 */
(function() {
	"user strict";
	/**
     * @ngdoc service
     * @name Hintservice
     * @module app.core
     * @requires $ionicPopup, $ionicLoading
     * @description
     * user for various kinds of the app hint
     *
     * @ngInject
     */
    function HintService($ionicPopup, $ionicLoading) {
    	return {
    		/**
             * @ngdoc method
             * @name HintService:comfirmHint
             * @params {string function} title, msg, callback
             * @description
             * popup a confirm message for user to  confirm his operation
             *
             */
    		comfirmHint: function(title, msg, callback) {
    			//create a confirmPopup
    			var confirmPopup = $ionicPopup.confirm({
				    title: 		title,
				    template: 	msg,
				    buttons: 	[
				        { text: '取消' },
				        { text: '<b>确定</b>',
				          type: 'button-calm',
				          onTap: function(e){ return true; }
				        }
				    ]
		        });

    			confirmPopup.then(function(res) {
    				if (res) {
    					callback();
    				}
    			})
    		},
    		/**
             * @ngdoc method
             * @name HintService:alertHint
             * @params {string} msg
             * @description
             * popup a alert message for user to notice an event
             *
             */
    		alertHint: function(msg) {
    			//create a alertPopup
    			var alertPopup = $ionicPopup.alert({
                    template: msg,
                    buttons:[
                       	{ text:  "确定",
                          type:  "button-calm",
                          ontap: function(e){ return true; }
                       	}
                    ]
                });

                alertPopup.then(function(res) {
                    return false;
                });
    		},
            /**
             * @ngdoc method
             * @name HintService:loadingtHint
             * @params {string} msg
             * @description
             * show a loading hint for user to notice an event
             *
             */
            loadingHint: function(msg) {
                var _template,
                    _duration;

                switch(msg) {
                    case undefined :
                        _template = '<ion-spinner icon="ripple" class="spinner-light"></ion-spinner>';
                        _duration = 3000;
                        break;
                    case 'update'  :
                        _template = "正在提交修改";
                        _duration = 3000;
                        break;
                    case 'complete':
                        _template = "修改成功";
                        _duration = 1000;
                        break;
                    case 'success' :
                        _template = "发送成功";
                        _duration  = 1000;
                        break;
                    case 'share' :
                        _template = "分享成功";
                        _duration  = 1000;
                        break;
                    case 'upload'  :
                        _template = '<ion-spinner icon="dots" class="spinner-light"></ion-spinner>';
                        break;
                    case 'fail':
                        _template = '上传失败';
                        _duration = 1000;
                        break;
                    case 'finish'  :
                        _template = '上传成功';
                        _duration = 1000;
                        break
                }

                $ionicLoading.show({
                    template : _template,
                    duration : _duration
                })
            }
    	}
    }




	angular
	.module('app.core')
	.factory('HintService', HintService)
})()
