/**
 *Profile service.
 *
 *@author  			Qian Chen 
 *@coplyright 		Copyright (c) 2015, zuber.im
 *@lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc service
     * @name ProfileService
     * @module app.core
     * @requires $http, Restangular, Token, Signature
     * @description
     * Service to get and modify the user data.
     *
     * @ngInject
     */
	function ProfileService($http, Restangular, Token, Signature) {
		return {
			createUserName: function(username) {
				var _uid   = Token.getApiUid();
				var _api   = 'users' + _uid + "/name";
				var _param = {
					username : username
				}
				Signature.set(_api, _param, 'post');

				return Restangular
				       .all(_api)
				       .post(_param);
			},

			/**
             * @ngdoc method
             * @name ProfileService:getUser
             * @description
             * get user information.
             *
             * @returns {promise} A promise which is resolved in user data.
             */
			getUser: function() {
				var _uid = Token.getApiUid();
				var _api = 'users' + _uid;
				Signature.set(_api, {}, 'get');

				return Restangular
					   .one(_api)
				       .get()
			},
			/**
             * @ngdoc method
             * @name ProfileService:getTags
             * @description
             * get user tags
             *
             * @returns {promise} A promise which is resolved in tag data.
             */
			getTags: function() {
				var _uid = Token.getApiUid();
				var _api = 'tags' + _uid;
				Signature.set(_api, {}, 'get');

				return Restangular
					   .one(_api)
				       .get()
			},
			setTags: function(params) {
				var _uid = Token.getApiUid();
				var _api = 'tags' + _uid;
				Signature.set(_api, params, 'put');

				return Restangular
					   .one(_api)
				       .customPUT(params)

			},
			/**
             * @ngdoc method
             * @name ProfileService:update
             * @description
             * update user profile
             *
             * @returns {promise} A promise which is resolved in result of update.
             */
			update: function(params) {
				var _uid = Token.getApiUid();
				var _api = 'users' + _uid;
				Signature.set(_api, params, 'put');

				return Restangular
					   .one(_api)
				       .customPUT(params)

			}
		}
	}

	angular
	.module('app.core')
	.factory('ProfileService', ProfileService)
})()