/**
 * Rent service.
 *
 * @author  			Qian Chen 
 * @coplyright 		Copyright (c) 2015, zuber.im
 * @lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc service
     * @name RentService
     * @module app.core
     * @requires $http, Restangular, Token, Signature
     * @description
     * Service to get, modify and create the mate states.
     *
     * @ngInject
     */
	function RentService($http, Restangular, Token, Signature) {
		return {
			/**
             * @ngdoc method
             * @name RentService:getRoomById
             * @description
             * get user rent states.
             *
             * @returns {promise} A promise which is resolved in get result.
             */
			getRoomInfo: function() {
				var _uid = Token.getApiUid();
				var _api = 'rooms' + _uid;
				Signature.set(_api, {}, 'get');

				return Restangular
					   .one(_api)
				       .get()
			},
			/**
             * @ngdoc method
             * @name RentService:Update
             * @description
             * update user rent information.
             *
             * @returns {promise} A promise which is resolved in update result.
             */
            update: function(params) {
            	var _uid = Token.getApiUid();
				var _api = 'rooms' + _uid;
				Signature.set(_api, params, 'put');

				return Restangular
					   .one(_api)
				       .customPUT(params);

            },
            /**
             * @ngdoc method
             * @name RentService:create
             * @description
             * update user rent information.
             *
             * @returns {promise} A promise which is resolved in update result.
             */
            create: function(params) {
                var _uid = Token.getApiUid();
                var _api = 'rooms' + _uid;
                Signature.set(_api, params, 'post');

                return Restangular
                       .all(_api)
                       .post(params);
            }
		}
	}

	angular
	.module('app.core')
	.factory('RentService', RentService)
})()