/**
 * Response service.
 *
 * @author  			Qian Chen
 * @coplyright 		Copyright (c) 2015, zuber.im
 * @lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc service
     * @name ResponseService
     * @module app.core
     * @requires $http, Restangular, Token, Signature
     * @description
     * Service to get the visit, browse data.
     *
     * @ngInject
     */
    function ResponseService(TEST_MODE, HintService, Token, $rootScope, $state) {
    	return {
    		handle: function(response, callback, failCallback) {

                switch (response.code) {
                    case 0:
                        callback();
                        break;
                    case 401:
                        if ( $rootScope.throwOnce ) {
                            $rootScope.loginState = false;
                            $rootScope.throwOnce  = false;

                            HintService.comfirmHint('登录信息失效', '请重新登录', function() {
                                Token.clear();
                                $state.go('app.dashboard');
                            });
                        } else {
                            return false;
                        }
                        break;
                    case 20003:
                        if ( $rootScope.throwOnce ) {
                            $rootScope.loginState = false;
                            $rootScope.throwOnce  = false;

                            HintService.comfirmHint('用户已被禁用', '该用户已被锁定，请联系管理员', function() {
                                Token.clear();
                                $state.go('app.dashboard');
                            });
                        } else {
                            return false;
                        }
                        break;
                    case 20004:
                        if ( $rootScope.throwOnce ) {
                            //$rootScope.loginState = false;
                            $rootScope.throwOnce  = false;
                            $rootScope.beginRegister = true;

                            HintService.comfirmHint('用户未绑定手机', '请绑定手机号后再使用该功能', function() {
                                $state.go('app.register_step3');
                            });
                        } else {
                            return false;
                        }
                        break;
                    case 30401:
                        HintService.comfirmHint('资料未填写完整', '请填写完善资料', function() {
                            $rootScope.ifNewAccount = true;
                            if ( $rootScope.me.user.xingzuo == "" || $rootScope.me.user.profession == "" ) {
                              $state.go('app.register_step1');
                            } else {
                              $state.go('app.register_step2');
                            }
                        });
                        break;
                    default:
                        if ( failCallback != undefined || null || "" ) {
                          failCallback();
                        }

                        HintService.alertHint(response.msg);
                        break;
                }
            }
    	}

    }


	angular
	.module('app.core')
	.factory('ResponseService', ResponseService)
})()
