/**
 *Follow service.
 *
 *@author  			Qian Chen 
 *@coplyright 		Copyright (c) 2015, zuber.im
 *@lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc service
     * @name FollowService
     * @module app.core
     * @requires $http, Restangular, Token, Signature
     * @description
     * Service to get the visit, browse data.
     *
     * @ngInject
     */
	function FollowService($http, Restangular, Token, Signature) {
		return {
			/**
             * @ngdoc method
             * @name FollowService:list
             * @description
             * get follow list.
             *
             * @returns {promise} A promise which is resolved in follow data.
             */
			list: function() {
				var _uid = Token.getApiUid();
				var _api = 'follows' + _uid;
				Signature.set(_api, {}, 'get');

				return Restangular
					   .one(_api)
				       .get();
			},
			/**
             * @ngdoc method
             * @name FollowService:unfollow
             * @description
             * unfollow an user.
             *
             * @returns {promise} A promise which is resolved in unfollow result.
             */
			unfollow: function(params) {
				var _uid = Token.getApiUid();
				var _api = 'follows' + _uid;
				Signature.set(_api, {}, 'delete');

				return Restangular
					   .one(_api)
					   .remove(params);
			},
			/**
             * @ngdoc method
             * @name FollowService:follow
             * @description
             * follow an user.
             *
             * @returns {promise} A promise which is resolved in follow result.
             */
			follow: function(params) {
				var _uid = Token.getApiUid();
				var _api = 'follows' + _uid;
				Signature.set(_api, params, 'post');

				return Restangular
					   .all(_api)
					   .post(params);
			}
		}
	}

	angular
	.module('app.core')
	.factory('FollowService', FollowService)
})()