/**
 * Social service.
 *
 * @author  			Qian Chen 
 * @coplyright 		Copyright (c) 2015, zuber.im
 * @lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc service
     * @name SocialService
     * @module app.core
     * @requires $http, Restangular, Token, Signature
     * @description
     * Service to get the visit, browse data.
     *
     * @ngInject
     */
	function SocialService($http, Restangular, Token, Signature) {
		return {
			/**
             * @ngdoc method
             * @name SocialService:visit
             * @description
             * get visit list.
             *
             * @returns {promise} A promise which is resolved in visit data.
             */
			visit: function() {
				var _uid = Token.getApiUid();
				var _api = 'visitors' + _uid  +"/latest";
				Signature.set(_api, {}, 'get');

				return Restangular
					   .one(_api)
				       .get()
			},
			/**
             * @ngdoc method
             * @name SocialService:browse
             * @description
             * get browse list.
             *
             * @returns {promise} A promise which is resolved in browse data.
             */
            browse: function() {
            	var _uid = Token.getApiUid();
				var _api = 'visitors' + _uid;
				Signature.set(_api, {}, 'get');

				return Restangular
					   .one(_api)
				       .get()
			}
		}
	}

	angular
	.module('app.core')
	.factory('SocialService', SocialService)
})()