/**
 * Gallery controller.
 *
 * @author  			Qian Chen
 * @coplyright 		Copyright (c) 2015, zuber.im
 * @lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc controller
     * @name GalleryCtrl
     * @module app.gallery
     * @description
     * Controller for the gallery page.
     *
     * @ngInject
     */
    function GalleryCtrl($rootScope, $scope, $cordovaImagePicker, ResponseService, localStorageService, GalleryService, HintService, CacheService, TEST_MODE) {
    	var zub = this,
            _uploadData;

        $rootScope.editable = true;

        zub.filelist = JSON.parse( localStorageService.get('gallery') );

        getFile();

        function getFile() {
            GalleryService.get().then(function(data) {
                ResponseService.handle(data, function() {
                    zub.count    = data.result.count;
                    zub.filelist = data.result.items;
                    _uploadData  = data.result.upload_data;

                    localStorageService.set('gallery', angular.toJson( zub.filelist ));
                    localStorageService.set('upload_data',angular.toJson( _uploadData ));

                    $scope.$broadcast('scroll.refreshComplete');
                })
            })
        }

        zub.doRefresh = function() {
            getFile();
        }

        zub.UploadImages = function() {
            var _limit  = _uploadData.limit,
                _url    = _uploadData.upload_url,
                _accept = _uploadData.accept;

            var options = {
                maximumImagesCount : _limit,
                width              : 1000,
                quality            : 100
            }

            if(TEST_MODE) {
                console.log(_limit, _url, _accept);
            }

            $cordovaImagePicker.getPictures(options)
            .then(function (results) {
                switch(true) {
                    case results.length == 0:
                        HintService.alertHint("您没有选择图片");
                        break;
                    case results.length > _limit:
                        HintService.alertHint("您不能上传超过" + _limit + "张图片");
                        break;
                    default:
                        HintService.loadingHint('upload');

                        GalleryService.getTokens({ count: results.length }).then(function(data) {
                            ResponseService.handle(data, function() {
                                for (var i = 0; i < results.length; i++) {
                                    GalleryService.upload(results[i], _url, data.result[i], _accept, function(){
                                        HintService.loadingHint('finish');
                                        getFile();
                                    });
                                }
                            })
                        }, function() {
                            HintService.loadingHint('fail');
                        });
                        break;
                }
            },function(err){
                console.log(err);
            })
        }
    }

	angular
	.module('app.gallery')
	.controller('GalleryCtrl',GalleryCtrl)
})()
