/**
 * Messages controller.
 *
 * @author  			Qian Chen 
 * @coplyright 		Copyright (c) 2015, zuber.im
 * @lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc controller
     * @name MessagesCtrl
     * @module app.messages
     * @description
     * Controller for the messages page.
     *
     * @ngInject
     */
    function MessagesCtrl($rootScope, $scope, $ionicModal, $state, $ionicPlatform, $timeout, $ionicListDelegate, MessageService, ResponseService, ModalService, Authentication, CommentService, MessageService, HintService, TEST_MODE) {
    	var zub           = this,
            _modal,
    		_receiveTotal = 1,
            _receivePage  = 0,
    		_sendTotal 	  = 1,
            _sendPage     = 0;

        var isiOS = !!navigator.userAgent.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/);

        zub.receiveList     = [];
        zub.receivehasmore  = true;
        zub.sendList        = [];
        zub.sendhasmore     = true;
        zub.reply_para      = {
            reply_id  :"",
            room_id   :"",
            content   :""
        }

        /**
         * @ngdoc method
         * @name CommentCtrl:getMessageList
         * @params {string number array boolean} category, currentPage, totalPage, resultList, ifHasmore
         * @description
         * get Message list.
         *
         */
        function getMessageList (category, ifReset) {
            switch (category) {
                case "receive":
                    if (ifReset) {
                        _receiveTotal = 1,
                        _receivePage  = 0,
                        zub.receivehasmore  = true;
                    }
                    if ( _receivePage < _receiveTotal ) {
                        _receivePage ++;
                        CommentService.list({page: _receivePage},'receive').then(function(data) {
                            ResponseService.handle(data, function() {
                                _receiveTotal = data.result.total_page;
                                if (ifReset) {
                                    zub.receiveList = (data.result.items) ? data.result.items : [] ;
                                    
                                } else {
                                    zub.receiveList = zub.receiveList.concat( (data.result.items) ? data.result.items : [] );
                                    
                                }    
                            })
                            $scope.$broadcast('scroll.infiniteScrollComplete');
                            $scope.$broadcast('scroll.refreshComplete');                         
                        });
                    } else {
                        zub.receivehasmore = false;
                    }
                    break;
                case "send":
                    if (ifReset) {
                        _sendTotal = 1,
                        _sendPage  = 0,
                        zub.sendhasmore  = true;
                    }
                    if ( _sendPage < _sendTotal ) {
                        _sendPage ++;
                        CommentService.list({page: _sendPage},'send').then(function(data) {
                            ResponseService.handle(data, function() {
                                _sendTotal = data.result.total_page;
                                if (ifReset) {
                                    zub.sendList = (data.result.items) ? data.result.items : [] ;
                                } else {
                                    zub.sendList = zub.sendList.concat( (data.result.items) ? data.result.items : []);
                                }    
                            });

                            $scope.$broadcast('scroll.refreshComplete');
                            $scope.$broadcast('scroll.infiniteScrollComplete');
                        });
                    } else {
                        zub.sendhasmore = false;
                    }
                    break;          
            }
            
        }
        
        function getNewestList () {
            
            if( $state.current.name == 'app.messages' && Authentication.isAuthenticated() ) {
                getMessageList('receive', true);
                
                $timeout(function() {
                    getMessageList('send', true);
                },500);

            } else if ( $state.current.name == 'app.messages' && !Authentication.isAuthenticated()){
                zub.receivehasmore = false;
                $scope.$broadcast('scroll.refreshComplete');
                $scope.$broadcast('scroll.infiniteScrollComplete');
            }
        }
    	//only the logged user can receive messages	
    	if ( !Authentication.isAuthenticated() ) {
            zub.receivehasmore = false;
            HintService.alertHint('您尚未登录');
        }

        $rootScope.$on('$stateChangeSuccess', function() {
            getNewestList();
        })

        $ionicPlatform.on('resume', function() {
            getNewestList();

            MessageService.notification().then(function(data) {

                if ( data.result == 1 ) {
                    $rootScope.hasNewMessage = true;
                    $rootScope.$digest();
                }
            })
        })

        zub.doScroll = function(category) {
            getMessageList(category, false);
        }
        zub.doRefresh = function(category) {
            getMessageList(category, true);
        }
        zub.removeMessage = function($event, $index, cid, category) {
            $event.preventDefault();
            $event.stopPropagation();
            
            HintService.comfirmHint('删除评论', '您确定要删除这条评论吗？', function(){
                MessageService.reset();

                if ( isiOS && !TEST_MODE && category == 'receive' && zub.receiveList[$index].read == 0 ) {
                    window.plugins.jPushPlugin.resetBadge();
                    window.plugins.jPushPlugin.setApplicationIconBadgeNumber(0);
                }
                
                CommentService.remove({cid: cid}).then(function(){
                    if ( category == 'receive' ) {
                        zub.receiveList.splice( $index, 1 );
                    } else {
                        zub.sendList.splice( $index, 1 );
                    }

                    $ionicListDelegate.closeOptionButtons()

                });
            })              
        }

        zub.checkMessage = function($event, $index, message) {
            $event.preventDefault();
            $event.stopPropagation();

            zub.currentMessage = message;

            MessageService.reset();

            if ( isiOS && !TEST_MODE ) {
                window.plugins.jPushPlugin.resetBadge();
                window.plugins.jPushPlugin.setApplicationIconBadgeNumber(0);
            }

            if ( message.read == 0 ) {
                CommentService.set({ cid: zub.currentMessage.id }).then(function(data) {
                    ResponseService.handle(data, function() {
                        zub.receiveList[$index].read = 1;            
                    });
                    
                })
            } 
            
            ModalService.createModal($scope, 'message.html').then(function(modal) {
                _modal = modal;
                _modal.show();

                zub.reply_para.reply_id = message.id;
                zub.reply_para.room_id  = message.room_id;

                zub.placeholder = "回复给 " + message.author ;

                zub.sendReply = function() {
                    if ( zub.reply_para.content == "" || undefined ) {
                        HintService.alertHint("您还没有填写任何内容");
                    } else {
                        _modal.remove();
                        
                        CommentService.reply(zub.reply_para).then(function(data) {
                            ResponseService.handle(data, function() {
                                HintService.loadingHint('success');
                                
                                zub.reply_para.content = "";
                                getMessageList('send', true);        
                            });
                        })
                    }   
                }
            })
            
        }
        zub.cancelReply = function() {
            _modal.remove();
        }

    }

	angular
	.module('app.messages')
	.controller('MessagesCtrl',MessagesCtrl)
})()