/**
 * Profile controller.
 *
 * @author  			Qian Chen 
 * @coplyright 		Copyright (c) 2015, zuber.im
 * @lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc controller
     * @name ProfileCtrl
     * @module app.profile
     * @description
     * Controller for the profile page.
     *
     * @ngInject
     */
    function ProfileCtrl($rootScope, $scope, $state, ResponseService, ProfileService, localStorageService, ModalService, HintService, TEST_MODE) {
        var zub       = this,
            _modal,
            _tagKey   = 'tags',
            _tagValue = '';

        zub.genders  = [
            { text: '男',   value: 'm' },
            { text: '女',   value: 'f' }
        ]

        zub.xingzuos = ["白羊座","金牛座","双子座","巨蟹座","狮子座","处女座","天秤座","天蝎座","射手座","摩羯座","水瓶座","双鱼座"]

        var _default  = {
            gender     : "m",
            xingzuo    : "",
            contact    : "",
            profession : ""
        }

        if ( localStorageService.get(_tagKey) ) {
            _tagValue  = JSON.parse( localStorageService.get(_tagKey) );

            zub.myTags   = _tagValue.include;
            zub.tagsPool = _tagValue.exclude;
        }

        if ( $rootScope.loginState ) {
            console.log($rootScope.me.user)

            var _profile = $rootScope.me.user;

            zub.profile = {
                gender     : _profile.gender,
                xingzuo    : _profile.xingzuo,
                contact    : _profile.contact,
                profession : _profile.profession
            };

        } else  {
            zub.profile = _default;
        }



        ProfileService.getTags().then(function(data) {
            ResponseService.handle(data, function() {
                _tagValue = data.result;
                localStorageService.set( _tagKey, angular.toJson(_tagValue) );

                zub.myTags   = _tagValue.include;
                zub.tagsPool = _tagValue.exclude;                    
            });
        })

        zub.addTags = function() {
            ModalService.createModal($scope, 'tag.html').then(function(modal) {

                _modal = modal;

                _modal.show();

                var _temp = _tagValue;

                zub.pushTag = function($index, tag) {
                    if ( _temp.include.length >=10 ) {
                        HintService.alertHint("您不能选择超过10个标签");
                    } else {
                        _temp.exclude.splice($index, 1);
                        _temp.include.push(tag);
                    }
                }

                zub.removeTag = function($index, tag) {
                    _temp.include.splice($index, 1);
                    _temp.exclude.push(tag);
                }

                zub.chooseTags = function() {
                    _tagValue = _temp;

                    zub.myTags   = _tagValue.include;
                    zub.tagsPool = _tagValue.exclude;

                    _modal.remove();
                }
            })
        }

        zub.cancel = function() {
            _modal.remove();
        }

        

        function validate() {
            switch(true) {
                case $rootScope.phoneSource && zub.username == undefined || "":
                    HintService.alertHint("请填写用户名");
                    return false;
                    break;
                case $rootScope.phoneSource && zub.profile.gender == "":
                    HintService.alertHint('请选择一个性别');
                    return false;
                    break;
                case zub.profile.xingzuo == "":
                    HintService.alertHint('请选择一个星座');
                    return false;
                    break;
                // case zub.profile.contact == "":
                //     HintService.alertHint('请填写联系方式');
                //     return false;
                //     break;
                case zub.profile.profession =="":
                    HintService.alertHint("请填写您的职业");
                    return false;
                    break;
                default:
                    return true;
                    break;
            }
        }

        zub.saveProfile = function() {

            if ( validate() ) {

                HintService.loadingHint('update');

                function getTagIds() {
                    var _tagArray = [];
                    
                    for ( var key in zub.myTags ) {
                        _tagArray.push(zub.myTags[key].id);
                    }
                    
                    return _tagArray;
                }

                if ( $rootScope.phoneSource ) {
                    ProfileService.createUserName(zub.username).then(function(data) {
                        ResponseService.handle(data, function() {
                            
                        })
                    })
                }
                //save profile and tags
                ProfileService.update( zub.profile ).then(function() { 
                    ProfileService.setTags( { ids: getTagIds() } ).then(function(data) { 
                        ResponseService.handle(data, function() {
                            
                            localStorageService.set( _tagKey, angular.toJson(_tagValue) );

                            if ( $rootScope.ifNewAccount ) {
                                $state.go("app.register_step2");
                            } else {
                                ProfileService.getUser().then(function(data) {
                                    $rootScope.me = data.result;
                                    localStorageService.set( "user", angular.toJson( data.result ) );
                                })
                            }
                            HintService.loadingHint('complete');        
                        }); 
                    });
                });
            }
            
        }

    }

	angular
	.module('app.messages')
	.controller('ProfileCtrl',ProfileCtrl)
})()