/**
 * Rent controller.
 *
 * @author  			Qian Chen
 * @coplyright 		Copyright (c) 2015, zuber.im
 * @lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc controller
     * @name RentCtrl
     * @module app.rent
     * @description
     * Controller for the rent page.
     *
     * @ngInject
     */
    function RentCtrl($rootScope, $scope, $filter, $ionicPlatform, $cordovaGeolocation, $state, $ionicHistory, ResponseService, RentService, ProfileService, GeoService, localStorageService, ModalService, HintService, TEST_MODE) {
        var zub         = this,
            _city       = ( !!localStorageService.get('city') ) ? localStorageService.get('city') : "Shanghai",
            _preCity,
            _modal,
            _region     = JSON.parse( localStorageService.get(_city+'&region') ),
            _railway    = JSON.parse( localStorageService.get(_city+'&railway') ),
            _limitaion  = 5,
            _today      = new Date(),
            _tempMark;

        zub.today  = _today - 1000;
        zub.cityClass = _city;
        zub.houses = [
            {text: "我已租房",value: '1'},
            {text: "我未租房",value: '0'}
        ]

        zub.cities = [
            { text: '北京', value: 'Beijing'   },
            { text: '上海', value: 'Shanghai'  },
            { text: '广州', value: 'Guangzhou' },
            { text: '深圳', value: 'Shenzhen'  }
        ]

        var _default = {
            house        : "",
            city         : "上海",
            region       : "",
            cost1        : "",
            address      : "",
            start_time   : "",
            subway       : [],
            content      : ""
        }

        zub.rent    = _default;
        zub.regions = _region;
        zub.railway = _railway;

        zub.preLine = {
            line           : "",
            station        : "",
            className      : ""
        }

        zub.selectedRailway = [];

        if ( localStorageService.get('rent') ) {

            zub.rent            = JSON.parse( localStorageService.get('rent') );
            zub.date            = new Date(zub.rent.start_time);
            zub.selectedRailway = zub.rent.subway;
            _tempMark           = zub.rent.content;
        }

        if ( !$rootScope.ifNewAccount ) {
            RentService.getRoomInfo().then(function(data) {

                ResponseService.handle(data, function() {
                    zub.rent.house      = data.result.room.house.toString();
                    zub.rent.city       = data.result.room.city;
                    _preCity            = zub.rent.city;

                    filterByCity();

                    zub.rent.region     = data.result.room.region;
                    zub.rent.cost1      = data.result.room.cost1;
                    zub.rent.address    = data.result.room.address;
                    zub.rent.start_time = data.result.room.start_time;
                    zub.date            = new Date(zub.rent.start_time);
                    zub.rent.subway     = data.result.subway;
                    zub.rent.content    = data.result.content.content;

                    _tempMark           = zub.rent.content;
                    zub.selectedRailway = zub.rent.subway;

                    localStorageService.set( 'rent', angular.toJson(zub.rent) );

                });

            })
        }
        /**
         *
         *
         * @description
         * when select line, list the station
         *
         */
        function filterByCity () {
            var city;

            for (var key in zub.cities) {
                if (zub.cities[key].text == zub.rent.city ) {
                    city = zub.cities[key].value;
                    localStorageService.set('city', city);
                }
            }


            GeoService.getRailwayByCity(city).success(function(data) {
                localStorageService.set(city+'&region', angular.toJson(data.result.region));
                _region     = data.result.region;
                zub.regions = data.result.region;

                localStorageService.set(city+'&railway', angular.toJson(data.result.railway));
                zub.railway = data.result.railway;
                _railway    = data.result.railway;
            });

            zub.cityClass = city;

            return city;
        }

        zub.switchCity = function() {
            if ( _preCity != zub.rent.city ) {
                zub.preLine         = {
                    line           : "",
                    station        : "",
                    className      : ""
                }
                zub.selectedRailway = [];
                zub.rent.subway     = [];
                zub.stations        = [];
            }
            _preCity = zub.rent.city;
            filterByCity();
        }

        zub.filterStation = function() {
            zub.stations = [];
            var _temp;
            zub.stationClassName = '';
            for (var key in zub.railway) {
                if ( zub.railway[key].line == zub.preLine.line ) {
                    zub.stationClassName  = zub.railway[key].classname;
                    zub.preLine.className = zub.stationClassName;
                    _temp                 = zub.railway[key].station;

                    for (var i = 0; i < _temp.length; i++ ) {
                        var _station = {
                            text    : zub.railway[key].station[i],
                            checked : checkSelected( zub.railway[key].line, zub.railway[key].station[i] )
                        }
                        zub.stations.push(_station);
                    }
                }
            }
        }
        /**
         *
         *
         * @description
         * when open modal, check if the station under specific line has been chosen, return false or true
         *
         */
        function checkSelected(line, station) {
            var _defaultChecked = false;

            for ( var key in zub.selectedRailway ) {
                if ( line == zub.selectedRailway[key].line ) {
                    var _checkStations = zub.selectedRailway[key].station.split(" ");
                    for (var i = 0; i < _checkStations.length; i++) {
                        if ( station == _checkStations[i] ) {
                            _defaultChecked = true;
                        }
                    }
                }
            }

            return _defaultChecked;
        }
        /**
         *
         * @description
         * open railway selection modal
         *
         */
        zub.editSubway = function() {
            ModalService.createModal($scope, 'subway.html').then(function(modal) {
                _modal = modal;

                _modal.show();
            })
        }
        /**
         *
         * @description
         * close railway selection modal
         *
         */
        zub.cancel = function() {
            _modal.remove();
        }
        /**
         *
         * @description
         * if has rented house, you can only choose on station
         *
         */
        zub.railwayLimit = function($index) {
            if ( zub.rent.house == '1' ) {
                for ( var i = 0; i < zub.stations.length; i++ ) {
                    if ( i != $index ) {
                        zub.stations[i].checked = false;
                    }
                }
            } else {
                var station_count = 0;

                for ( var j = 0; j < zub.stations.length; j++ ) {
                    if ( zub.stations[j].checked ) {
                        station_count ++;

                        if ( station_count > _limitaion ) {
                            zub.stations[$index].checked = false;
                            HintService.alertHint( "您不能选择超过" + _limitaion + "个站点" );
                            break;
                        }
                    }
                }
            }
        }
        /**
         *
         * @description
         * when filter house condition, reset railway line data
         *
         */
        zub.checkRailway = function() {
            if (zub.rent.house == '1' ) {
                zub.preLine = {
                    line           : "",
                    station        : "",
                    className      : ""
                }
                zub.stations = [];
                zub.selectedRailway = [];
            }
        }
        /**
         *
         * @description
         * add chooesd line&station to the selected railway lines
         *
         */
        zub.addSubway = function() {

            var _temp = [];

            for( var key in zub.stations ) {
                if ( zub.stations[key].checked ) {
                    _temp.push( zub.stations[key].text );
                }
            }

            zub.preLine.station = _temp.join(" ");

            var _addItem = {
                line      : zub.preLine.line,
                station   : zub.preLine.station,
                className : zub.preLine.className
            }
            //if has rented, can only choose one line and one station
            if ( zub.rent.house == '1' ) {
                zub.selectedRailway = [];
                zub.selectedRailway.push( _addItem );

            } else {
            //if hasn't rented, can choose multiple lines and stations under limitation

                var _defaultSelected = false;

                for ( var key in zub.selectedRailway ) {
                    if ( _addItem.line == zub.selectedRailway[key].line ) {
                        _defaultSelected         = true;
                        zub.selectedRailway[key] = _addItem;
                        break;
                    }
                }

                if (!_defaultSelected) {
                    if ( zub.selectedRailway.length >= _limitaion ) {
                        HintService.alertHint("您不能选择超过" + _limitaion + "条地铁线路");
                    } else {
                        zub.selectedRailway.push( _addItem );
                    }
                }
            }

            _modal.remove();
        }
        /**
         *
         * @description
         * remove specific line
         *
         */
        zub.removeLine = function($index) {
            zub.selectedRailway.splice($index, 1)
        }
        /**
         *
         * @description
         * open mark panel
         *
         */
        zub.editMark = function() {
            ModalService.createModal($scope, 'mark.html').then(function(modal) {
                _modal = modal;

                _modal.show();

                _tempMark = zub.rent.content;
            })
        }
        /**
         *
         * @description
         * confirm mark
         *
         */
        zub.cancelMark = function() {
            zub.rent.content = _tempMark;

            _modal.remove();
        }
        /**
         *
         * @description
         * validate user input
         *
         */
        function validate() {
            switch(true) {
                case zub.rent.house == "":
                    HintService.alertHint("请选择您的租房状态");
                    return false;
                    break;
                case zub.rent.house == '1' && zub.rent.region  =="":
                    HintService.alertHint("请选择您的区域");
                    return false
                    break;
                case zub.rent.house == '1' && zub.rent.address == "":
                    HintService.alertHint("请填写您的具体住址");
                    return false;
                    break;
                case zub.rent.cost1 =="":
                    var _text = ( zub.rent.house == '1' ) ? '租金' : '预算';
                    HintService.alertHint("请填写" + _text);
                    return false;
                    break;
                case zub.rent.cost1 < 100:
                    var _text = ( zub.rent.house == '1' ) ? '租金' : '预算';
                    HintService.alertHint( _text + '不得小于100' );
                    return false;
                    break;
                case zub.date == undefined:
                    HintService.alertHint("请填写一个晚于今日的入住日期");
                    return false;
                    break;
                case zub.rent.house == '0' && zub.selectedRailway.length == 0:
                    HintService.alertHint("请添加您期望地段的地铁线路");
                    return false;
                    break;
                case zub.rent.house == '1' && ( zub.selectedRailway.length == 0 || ( zub.selectedRailway.length == 1 && zub.selectedRailway[0].station == "" ) ):
                    HintService.alertHint("请添加距您住房最近的地铁站");
                    return false;
                    break;
                default:
                    return true;
                    break;
            }
        }
        /**
         *
         * @description
         * update rent info
         *
         */
        zub.saveRent = function() {

            if ( validate() ) {
                HintService.loadingHint('update');


                zub.rent.start_time = $filter('date')(zub.date, 'yyyy-MM-dd');
                zub.rent.subway     = zub.selectedRailway;

                if ( !$rootScope.ifNewAccount ) {


                    RentService.update(zub.rent).then(function(data) {
                        ResponseService.handle(data, function() {
                            HintService.loadingHint('complete');
                            localStorageService.set( 'rent', angular.toJson(zub.rent) );
                        });

                    })
                } else {
                    RentService.create(zub.rent).then(function(data) {

                        $rootScope.phoneSource   = false;

                        ProfileService.getUser().then(function(data) {
                            ResponseService.handle(data, function() {

                                HintService.loadingHint('complete');

                                $rootScope.me           = data.result;
                                $rootScope.ifBindPhone  = (data.result.user.phone != "") ? true : false;

                                if( !$rootScope.ifBindPhone ) {
                                    $state.go('app.register_step3');
                                } else {
                                    $ionicHistory.nextViewOptions({
                                        disableBack: true
                                    });

                                    $rootScope.ifNewAccount  = false;
                                    $rootScope.beginRegister = false;
                                    $state.go('app.dashboard');
                                }

                                localStorageService.set( "user", angular.toJson( data.result ) );
                            });
                        });
                    })
                }


            }
        }
        /**
         *
         * @description
         * get map location
         *
         */
        zub.locating = false;

        document.addEventListener('deviceready', function() {
            zub.locatePosition = function() {
                zub.locating = true;

                var geolocationSuccess = function(position) {
                    zub.locating        = false;

                    console.log('geo: '+angular.toJson(position));

                    GeoService.map({ coords: position.coords.longitude+","+position.coords.latitude })
                    .then(function(data) {
                        zub.rent.city       = data.result.city;

                        console.log('address: '+angular.toJson(data));

                        filterByCity();

                        zub.rent.region     = data.result.region;
                        zub.rent.address    = data.result.address;
                        zub.rent.subway     = data.result.subway;
                        zub.selectedRailway = zub.rent.subway;
                    })
                }

                var geolocationFail = function(geolocationError) {
                    zub.locating = false;
                    HintService.alertHint("暂时无法获取当前位置");
                    console.log(angular.toJson(geolocationError));
                }

                var geoOptions = { maximumAge: 3000, timeout: 5000, enableHighAccuracy: true };

                navigator.geolocation.getCurrentPosition(geolocationSuccess, geolocationFail, geoOptions);

            }
        }, false)


    }

	angular
	.module('app.rent')
	.controller('RentCtrl',RentCtrl)
})()
