/**
 *Search controller.
 *
 *@author  			Qian Chen
 *@coplyright 		Copyright (c) 2015, zuber.im
 *@lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc controller
     * @name SearchCtrl
     * @module app.search
     * @description
     * Controller for the roomsearch page.
     *
     * @ngInject
     */
    function SearchCtrl($rootScope, $scope, $ionicModal, $ionicScrollDelegate, $filter, ResponseService, localStorageService, HintService, SearchService, GeoService, TEST_MODE) {
        var _date = new Date();

        var zub         = this,
            _city       = ( localStorageService.get('city') != null ) ? localStorageService.get('city') : "Shanghai",
            _totalPage  = 1,
            today       = _date - 10000,
            thisMonth   = _date.setDate(1),
            nextMonth   = _date.setMonth(_date.getMonth()+1),
            search_panel,
            _region     = JSON.parse( localStorageService.get(_city+'&region') ),
            _railway    = JSON.parse( localStorageService.get(_city+'&railway') ),
            _divider    = JSON.parse( localStorageService.get(_city+'&divider') );

        $ionicModal.fromTemplateUrl('search-condition.html', {
            scope:      $scope,
            animation:  'slide-in-up'
        }).then(function(modal){
            search_panel = modal;
        });

        zub.cityClass = _city;
        //initial room search list
        zub.result = [];
        //initial the hasmore condition
        zub.hasmore = true;
        //initial room search condition
        zub.cities = [
            { text: '北京', value: 'Beijing'   },
            { text: '上海', value: 'Shanghai'  },
            { text: '广州', value: 'Guangzhou' },
            { text: '深圳', value: 'Shenzhen'  }
        ]

        zub.genders = [
            { text: '男',   value: 'm' },
            { text: '女',   value: 'f' },
            { text: '不限', value: '' }
        ]

        zub.houses =  [
            { text: '已租房',   value: '1' },
            { text: '未租房',   value: '0' }
        ]

        zub.pricesection = [
            { text: '2k以下',    value: '0'},
            { text: '2k-3k',    value: '1'},
            { text: '3k-4k',    value: '2'},
            { text: '4k以上',    value: '3'}
        ]

        zub.dateRange = [
            { text: '本月',    value: $filter('date')(thisMonth, 'yyyy-MM-dd') },
            { text: '下月',    value: $filter('date')(nextMonth, 'yyyy-MM-dd') }
        ]

        zub.changeCost = function() {
            switch(zub.cost) {
                case '0':
                    zub.searchCondition.cost1 = "";
                    zub.searchCondition.cost2 = 2000;
                    break;
                case '1':
                    zub.searchCondition.cost1 = 2000;
                    zub.searchCondition.cost2 = 3000;
                    break;
                case '2':
                    zub.searchCondition.cost1 = 3000;
                    zub.searchCondition.cost2 = 4000;
                    break;
                case '3':
                    zub.searchCondition.cost2 = "";
                    zub.searchCondition.cost1 = 4000;
                    break;
            }
        }

        function getCity (value) {
            var city;
            for ( var key in zub.cities ) {
                if ( zub.cities[key].value == value ) {
                    city = zub.cities[key].text;
                }
            }
            return city;
        }

        zub.region = _region;

        zub.railway = _railway;

        var _default = {
            sequence:        "",
            city:            getCity(_city),
            region:          "",
            subway_line:     "",
            subway_station:  "",
            start_time:      "",
            house:           "1",
            page:            0,
            cost1:           "",
            cost2:           "",
            sex:             ""
        };

        function getTrafficByCity (city) {
            zub.cityClass = city;

            GeoService.getRailwayByCity(city).success(function(data) {
                localStorageService.set(city+'&region', angular.toJson(data.result.region));
                _region    = data.result.region;
                zub.region = data.result.region;

                localStorageService.set(city+'&railway', angular.toJson(data.result.railway));
                zub.railway = data.result.railway;
                _railway    = data.result.railway;
            });
            //get divider
            GeoService.getDividerFilterByCity(city).success(function(data) {
                localStorageService.set(city+'&divider', angular.toJson(data.result));
                _divider = data.result;
            })
        }

        if (!_region) {
            getTrafficByCity(_city);
        }


        //initial model
        zub.searchCondition = _default;

        //zub.date = '';

        // function getDate() {
        //     return $filter('date')(zub.date, 'yyyy-MM-dd');
        // }
        //return parameter
        function getPara() {
            var parameter = {};
            for (var key in zub.searchCondition) {
                parameter[key] = zub.searchCondition[key];
            }
            return parameter;
        }
        //excute search
        zub.processing = false;

        function doSearch(ifRest) {
            var _ifMulti = ( zub.searchCondition.house == '0' && zub.searchCondition.subway_line !="" ) ? true :false

            SearchService.list(_ifMulti, getPara()).then(function(data){
                ResponseService.handle(data, function() {
                    _totalPage                    = data.result.total_page;
                    zub.searchCondition.sequence  = data.result.sequence;

                    if ( zub.searchCondition.page < _totalPage ) {
                        zub.hasmore = true;
                    } else {
                        zub.hasmore = false;
                    }

                    if (ifRest) {
                        zub.result = data.result.items;

                    } else {
                        zub.result = zub.result.concat( data.result.items );
                    }

                    zub.processing = false;
                    $scope.$broadcast('scroll.refreshComplete');
                    $scope.$broadcast('scroll.infiniteScrollComplete');
                });

            });
        }

        zub.doRefresh = function() {
            //reset page
            zub.processing               = true;
            zub.searchCondition.page     = 1;
            zub.searchCondition.sequence = "";
            doSearch(true);
            search_panel.hide();
            $ionicScrollDelegate.scrollTop(true);
        }

        zub.doScroll = function() {
            //page ++
            if (TEST_MODE) {
                console.log("current_page="+zub.searchCondition.page+"&"+"total_page="+_totalPage);
            }
            if ( zub.searchCondition.page < _totalPage) {
                zub.searchCondition.page ++;
                doSearch(false);
            } else {
                $scope.$broadcast('scroll.infiniteScrollComplete');
            }
        }

        zub.resetStations = function() {
            zub.searchCondition.subway_station = "";
            _tempMultiStations = [];
        }

        zub.filterRegion = function(city) {
            zub.searchCondition.page           = 0;
            _totalPage                         = 1;
            zub.searchCondition.subway_line    = "";
            zub.searchCondition.subway_station = "";
            zub.stations                       = [];
            zub.multiStations                  = [];
            _tempMultiStations                 = [];
            getTrafficByCity(city);
        }

        zub.filterLine = function() {
            //reset railway search condition
            zub.railway                        = [];
            zub.stations                       = [];
            zub.multiStations                  = [];
            _tempMultiStations                 = [];
            zub.searchCondition.subway_line    = "";
            zub.searchCondition.subway_station = "";
            for (var key in _divider) {
                if ( _divider[key].region == zub.searchCondition.region ) {
                    zub.railway = _divider[key].railway;
                }
            }
        }

        zub.filterStation = function() {
            zub.stations                       = [];
            zub.multiStations                  = [];
            _tempMultiStations                 = [];
            zub.stationClassName               = '';
            zub.searchCondition.subway_station = "";
            for (var key in zub.railway) {
                if ( zub.railway[key].line == zub.searchCondition.subway_line ) {
                    zub.stationClassName = zub.railway[key].classname;
                    zub.stations = zub.railway[key].station;
                }
            }

            for (var key in zub.stations) {
                var temp = {
                    text    : zub.stations[key],
                    checked : false
                }
                zub.multiStations.push(temp);
            }
        }

        var  _tempMultiStations = [];

        zub.railwayLimit = function($index) {

            _tempMultiStations = [];

            for (var key in zub.multiStations) {
                if (zub.multiStations[key].checked) {

                    if (_tempMultiStations.length >= 5 ) {
                      zub.multiStations[$index].checked = false;
                      HintService.alertHint("您不能选择超过5个地铁站");
                    } else {
                      _tempMultiStations.push( zub.multiStations[key].text );
                    }

                }
            }

            zub.searchCondition.subway_station = _tempMultiStations.join(',');
        }

        zub.filter = function() {
            search_panel.show();
        }
        zub.cancel = function() {
            search_panel.hide();
        }

        zub.reset = function(item) {
            switch(item) {
                case 'city':
                    zub.searchCondition.city           = "";
                    zub.searchCondition.region         = "";
                    zub.searchCondition.subway_line    = "";
                    zub.searchCondition.subway_station = "";
                    zub.railway                        = _railway;
                    zub.stations                       = [];
                    zub.multiStations                  = [];
                    _tempMultiStations                 = [];
                    break;
                case 'region':
                    zub.searchCondition.region         = "";
                    zub.searchCondition.subway_line    = "";
                    zub.searchCondition.subway_station = "";
                    zub.railway                        = _railway;
                    zub.stations                       = [];
                    zub.multiStations                  = [];
                    _tempMultiStations                 = [];
                    break;
                case 'line':
                    zub.searchCondition.subway_line    = "";
                    zub.searchCondition.subway_station = "";
                    zub.stations                       = [];
                    zub.multiStations                  = [];
                    _tempMultiStations                 = [];
                    break;
                case "station":
                    zub.searchCondition.subway_station = "";
                    break;
                case "cost":
                    zub.searchCondition.cost1 = "";
                    zub.searchCondition.cost2 = "";
                    zub.cost = "";
                    break;
                case "date":
                    zub.searchCondition.start_time = "";
                    break;
            }
        }

    }


	angular
	.module('app.roomsearch')
	.controller('SearchCtrl',SearchCtrl)
})()
