/**
 * Dashboard controller.
 *
 * @author  			Qian Chen
 * @coplyright 		Copyright (c) 2015, zuber.im
 * @lincence
 */
(function () {
    'use strict';

    /**
     * @ngdoc controller
     * @name DashboardCtrl
     * @module app.dashboard
     * @requires $state
     * @requires localStorageService, Authentication
     * @description
     * Controller for the dashboard page.
     *
     * @ngInject
     */
    function SigninCtrl($scope, $state, $rootScope, $ionicHistory, RegisterService, ResponseService, HintService, localStorageService, ProfileService, Authentication, TEST_MODE) {
        var zub          = this,
            _logged      = $rootScope.loginState,
            _sourcekey   = 'source',
            _sourceValue = localStorageService.get(_sourcekey);


        if (!TEST_MODE) {
            Wechat.isInstalled(function (installed) {
                zub.wechat = installed;
            }, function (reason) {
                throw new Error(reason);
            });
        }

        zub.register   = false;

        zub.processing = false;

        zub.switchSign = function(category) {

            zub.password     = "";
            zub.captcha      = "";

            switch(category) {
                case 'register':
                    zub.register = true;
                    break;
                case "login":
                    zub.register = false;
                    zub.reset    = false;
                    break;
                case "reset":
                    zub.register = true;
                    zub.reset    = true;
                    break;
            }
        }



        function validate() {
            switch(true) {
                case zub.phone == undefined || "":
                     HintService.alertHint("请填写手机号");
                     return false;
                     break;
                case !zub.phone.match(/^(0|86|17951)?(13[0-9]|15[012356789]|17[678]|18[0-9]|14[57])[0-9]{8}$/):
                     HintService.alertHint("您的手机号不合法");
                     return false;
                     break;
                case zub.register && zub.captcha == "":
                     HintService.alertHint('请填写验证码');
                     return false;
                     break;
                case zub.password == null:
                     HintService.alertHint('请填写密码');
                     return false;
                     break;
                default:
                    return true;
                    break;
            }
        }

        zub.sendCaptcha = function() {
            if ( zub.phone == undefined || "" ) {
                HintService.alertHint("请填写手机号")
            } else if (!zub.phone.match(/^(0|86|17951)?(13[0-9]|15[012356789]|17[678]|18[0-9]|14[57])[0-9]{8}$/)) {
                HintService.alertHint("您的手机号不合法");
            } else {
                zub.captchaDelay = true;
                zub.seconds      = 60;

                var ifnew = (zub.reset) ? 0 : 1;

                RegisterService.getCaptcha(zub.phone, ifnew).then(function(data) {

                    ResponseService.handle(data, function() {
                        var secondCount = setInterval(function() {
                            if( zub.seconds == 0 ) {
                                zub.captchaDelay = false;
                                $scope.$apply();
                                clearInterval(secondCount);
                            }

                            zub.seconds--;
                            $scope.$apply();


                        }, 1000);
                    }, function() {
                        zub.captchaDelay = false;
                    })

                });
            }

        }

        zub.phoneRegister = function() {

            if ( validate() ) {
                zub.processing = true;
                RegisterService.phoneRegist(zub.phone, zub.captcha, zub.password, zub.reset).then(function(data) {
                    zub.processing = false;
                    console.log(data);
                })
            }

        }

        zub.phoneLogin = function() {
            if ( validate() ) {
                zub.processing = true;
                RegisterService.phoneLogin(zub.phone, zub.password).then(function(data) {
                    zub.processing = false;
                    console.log(data);
                })
            }
        }


        document.addEventListener('deviceready', function() {

            if ( _logged ) {
                zub.me = JSON.parse( localStorageService.get('user') );
            }

            zub.login = function(source) {
                _sourceValue = source;
                localStorageService.set(_sourcekey, _sourceValue);

                Authentication.signin(source)
            }
        })

    }

    angular
        .module('app.signin')
        .controller('SigninCtrl', SigninCtrl);
})();
