/**
 *User controller.
 *
 *@author  			Qian Chen 
 *@coplyright 		Copyright (c) 2015, zuber.im
 *@lincence
 */
(function() {
	'user strict';

	/**
     * @ngdoc controller
     * @name UserCtrl
     * @module app.user
     * @description
     * Controller for the user detail page.
     *
     * @ngInject
     */
    function UserCtrl($rootScope, $scope, $state, $stateParams, $ionicLoading, $ionicActionSheet, ShareService, ResponseService, FollowService, UserService, CommentService, HintService, ModalService, localStorageService, TEST_MODE) {
        var zub = this,
            _userKey = $stateParams.UserID,
            _roomKey,
            _page    = 1,
            _total   = 1,
            _modal;
            
        $rootScope.editable = false;
        
        zub.comments    = [];
        zub.hasmore     = true;
        zub.accessRoute = getAccessRoute();
        zub.reply_para  = {
            room_id  : "",
            reply_id : "",
            content  : ""
        }
        
        function getAccessRoute() {
            var _source = $state.current.url.split("/");
            _source.shift();
            _source.pop();

            return _source.join("/");
        }
        function loadComments(ifreset) {
            CommentService.getListByRid({ rid: _roomKey, page: _page}).then(function(data) {
                ResponseService.handle(data, function() {

                    _total       = data.result.total_page;

                    if (ifreset) {
                        zub.comments = data.result.items;
                    } else {
                        zub.comments = zub.comments.concat( data.result.items );
                    }
                    
                    $scope.$broadcast('scroll.infiniteScrollComplete')            
                });                    
            });
        }
        
        //checking if this user information was cached before
        if ( localStorageService.get( _userKey ) != null && localStorageService.get( _userKey )!= '[]' ) {
            zub.item                = JSON.parse( localStorageService.get( _userKey ) );
             _roomKey               = zub.item.room.id;
             zub.reply_para.room_id = _roomKey;
             zub.following          = zub.item.follow;
             zub.LoadingComplete    = true;
        } else {
            zub.LoadingComplete = false;
            //HintService.loadingHint();
        }

        function loadUser() {
            UserService.getUserById({ object_uid: _userKey }).then(function(data) {
                ResponseService.handle(data, function() {

                    $scope.$broadcast("scroll.refreshComplete");
                    
                    zub.LoadingComplete = true;
                    //$ionicLoading.hide();
                    //get user information and save to local storage
                    var _userValue = angular.toJson( data.result );
                    localStorageService.set(_userKey, _userValue);
                    //refresh current user
                    zub.item               =  data.result;
                    _roomKey               =  zub.item.room.id;
                    zub.reply_para.room_id =  _roomKey;
                    zub.following          =  zub.item.follow;

                    loadComments(true);                
                });   
            })
        }

        loadUser();
            

        zub.doRefresh = function() {
            loadUser();
        }

        zub.doScroll = function() {
            if (_page < _total) {
                zub.hasmore     = true;
                _page++;
                loadComments(false);
            } else {
                zub.hasmore = false;
            }
        }
        zub.followUser = function(id) {
            zub.following = true;
            FollowService.follow({ object_uid: id }).then(function(data) {
                ResponseService.handle(data, function() {
                    return;            
                });
                
            });
        }
        zub.unfollowUser = function(id) {
            zub.following = false;
            FollowService.unfollow({ object_uid: id }).then(function(data) {
                ResponseService.handle(data, function() {
                    return;            
                });
                
            });
        }
        zub.replyComment = function($event, author, cid) {
            $event.preventDefault();
            $event.stopPropagation();
            
            ModalService.createModal($scope, 'reply.html').then(function(modal) {
                _modal = modal;

                _modal.show();

                zub.reply_para.reply_id = ( !cid ) ? "" : cid ;

                zub.placeholder = ( !cid ) ? "留言给 " + author : "回复 " + author ;

                zub.sendReply = function() {
                    _modal.remove();

                    CommentService.reply(zub.reply_para).then(function(data) {
                        ResponseService.handle(data, function() {
                            HintService.loadingHint('success');
                            
                            _page = 1;
                            zub.reply_para.content = "";
                            loadComments(true);    
                        });
                    })
                }
            })
        }
        zub.cancelReply = function() {
            _modal.remove();
        }
        zub.removeComment = function($event, $index, cid) {
            $event.preventDefault();
            $event.stopPropagation();
            
            HintService.comfirmHint('删除评论', '您确定要删除这条评论吗？', function(){
                CommentService.remove({cid: cid}).then(function(){
                    zub.comments.splice($index ,1)
                });
            })              
        }

        var weixinInstalled;

        Wechat.isInstalled(function (installed) {
               weixinInstalled = installed;
            }, function (reason) {
                throw new Error(reason);
        });

        zub.share = function() {
            var buttons = (weixinInstalled) ? [{ text: '分享到微博' },{ text: '分享给微信好友' },{ text: '分享到微信朋友圈' }] : [{ text: '分享到微博'}]

            var title       = zub.item.user.username,
                description = zub.item.content.replace(/<[^>]+>/g,""),
                imageUrl    = zub.item.user.share_avatar,
                url         = 'http://www.zuber.im/user/view/' + zub.item.user.id,
                text        = zub.item.content.replace(/<[^>]+>/g,"")

            var hideSheet = $ionicActionSheet.show({
                buttons: buttons,
                titleText: '将Ta',
                cancelText: '取消',
                cancel:      function() {
                    hideSheet();
                },
                buttonClicked: function(index) {
                    switch (index) {
                        case 0:
                            ShareService.weiboShare(title, description, imageUrl, url, text);
                            hideSheet();
                            break;
                        case 1:
                            ShareService.weixinShare(title, description, imageUrl, url, text, 'friends');
                            hideSheet();
                            break;
                        case 2:
                            ShareService.weixinShare(title, description, imageUrl, url, text, 'timeline');
                            hideSheet();
                            break;
                    }
                }
            })
        }
            
    }


	angular
	.module('app.user')
	.controller('UserCtrl',UserCtrl)

})()